% This function prices a double knockin call barrier option 
% 
%   NOTE:   This function was written for use in conjuntion with the 
%           function EuropeanDoubleKnockoutCall(), also found on 
%           www.volopta.com
% 
% Written by:   Michael Wencis, 2008
% Package:      MATLAB 7.5.0 with Statistics Toolbox
% 
% Option Definition:
% This instrument gives you a standard European vanilla type option when
% the underlying price hits either of the barriers during the option's
% lifetime.  If the underlying price is always inside the two barriers
% during the option's lifetime, it pays a cash rebate on the option
% maturity date.
% 
% Parameters:
% S:      spot rate
% K:      strike price
% U:      upper barrier
% L:      lower barrier
% rd:     domestic risk-free rate
% rf:     foreign risk-free rate
% sd:     volatility
% T:      time to maturity (actual/365)
% BH:     logical.  barrier hit?
%   
% function call: EuropeanDoubleKnockinCall(S,K,U,L,rd,rf,sd,T,BH)

function price = EuropeanDoubleKnockinCall(S,K,U,L,rd,rf,sd,T,BH)
% First calculate the price for a vanilla call 
vd1 = (log(S/K) + (rd-rf+.5*sd*sd)*T)/(sd*sqrt(T));
vd2 = vd1 - sd*sqrt(T);
vanillaCall = S*exp(-rf*T)*normcdf(vd1) - K*exp(-rd*T)*normcdf(vd2);

% Use the above calculation to derive the value of the Double knockin call
price = vanillaCall - EuropeanDoubleKnockoutCall(S,K,U,L,rd,rf,sd,T,BH);